@@ -255,10 +255,13 @@ class vinex (Exchange):
             else:
                 result['side'] = 'sell'
 
-            fee_percent = self.safe_float(trade, 'feePercent')
+            # fee_percent = self.safe_float(trade, 'feePercent')
+            #
+            # cost = price * amount * fee_percent
+            # fee_currency = market['quote']
 
-            cost = price * amount * fee_percent
-            fee_currency = market['quote']
+            cost = self.safe_float(trade, 'fee')
+            fee_currency = self.safe_string(trade, 'feeAsset')
 
             result['fee'] = {
                 'cost': cost,
